<?php
  /*
    Parses the json and splits it in global, page and menu settings depending on the "pages" value or the name
    of the setting itself.
    Creates the $global_settings variable which is an assosiative array and puts all the settings marked as global.
    Injects the menu settings inside the corresponding menu items.
    Creates the $local_settings assosiative array. It passes all the settings whose value on pages attribute maches
    the current URI.
    Lastly it takes action for certain settings that need to be executed first such as the default language.
  */
  // First pass the menu here.
  $mainMenu = $template['menu'];

  // Init global settings
  $global_settings = [
    'hideHomeMap' => 'false',
    'hideEmail' => 'false',
    'hideCategory' => 'false',
    'hideVisits' => 'false',
    'hideWebsite' => 'false',
    'amea' => 'false',
    'headerText' => 'false',
    'bubbles' => 'false',
    'fixedBanner' => false,
    'logoSize' => false
  ];

  if ($template['json']) {
    $page_settings = json_decode($template['json'], true, 10);

    // List of all possible menu settings
    $menu_settings_list = array(
      'hide', 'highlight', 'hideSubmenus', 'removeMenu',
      'iconLeft', 'iconRight', 'iconTop', 'iconBottom',
      'iconFull'
    );

    // Iterate over the $page_settings and categorize them in local and global
    // settings.
    foreach ($page_settings as $skey => $svalue) {

      // First check if this is a global setting.
      if ($svalue['pages'] == 'global') {

        $global_settings[$skey] = $svalue['value'];
        // Recreate the menu.
				if (isset($global_settings['mainMenu'])) {
					$mainMenu['items'] = $svalue['value'];
				}

      } else {

        // If it is not a global setting then it must be a menu or a local
        // setting.
        // Convert pages into an array.
        $pages = explode(',', $svalue['pages']);

        // Check if this is a menu setting. If it is find the menu item(s) this
        // setting is for. And pass its value to their settings attribute.
        if (in_array($skey, $menu_settings_list) || substr($skey, 0, 3) == 'url' || substr($skey, 0, 9) == 'urlNewTab') {
          // Find menu item(s) this setting is for.
          foreach ($mainMenu['items'] as $item => $item_contents) {
            foreach ($pages as $page) {
              $pageURI = trim($page);
              if (substr($item_contents['url'], -strlen($pageURI)) == $pageURI) {
                $mainMenu['items'][$item]['settings'][$skey] = $svalue['value'];
              }
            }
            // Check the sub menus
            if ($item_contents['dropdown']) {
              foreach ($item_contents['subMenu'] as $subItem => $subItem_contents) {
                foreach ($pages as $page) {
                  $pageURI = trim($page);
                  if (substr($subItem_contents['url'], -strlen($pageURI)) == $pageURI) {
                    $mainMenu['items'][$item]['subMenu'][$subItem]['settings'][$skey] = $svalue['value'];
                  }
                }
                // Check the sub sub menus
                if ($subItem_contents['dropdown']) {
                  foreach ($subItem_contents['subMenu'] as $subSubItem => $subSubItem_contents) {
                    foreach ($pages as $page) {
                      $pageURI = trim($page);
                      if (substr($subSubItem_contents['url'], -strlen($pageURI)) == $pageURI) {
                        $mainMenu['items'][$item]['subMenu'][$subItem]['subMenu'][$subSubItem]['settings'][$skey] = $svalue['value'];
                      }
                    }
                  }
                }
              }
            }
          }

        } else {

          // If this is not a menu setting then it must be a local setting.
          // Iterate over the settings' pages. Check if the current URI is in
          // the settings' pages array. If it is then pass it in the
          // $local_settings.
          foreach ($pages as $page) {
            $pageURI = count(explode('?l=',trim($page))) > 1 ? explode('?l=',trim($page))[0] : trim($page);

            // Local settings.

            $request_uri = count(explode('?_ga',$_SERVER['REQUEST_URI'])) > 1 ? explode('?_ga',$_SERVER['REQUEST_URI'])[0] : $_SERVER['REQUEST_URI'];
            $request_uri = count(explode('?l=',$_SERVER['REQUEST_URI'])) > 1 ? explode('?l=',$_SERVER['REQUEST_URI'])[0] : $request_uri;
            $request_uri = substr($request_uri,-1) == '?' ? explode('?',$_SERVER['REQUEST_URI'])[0] : $request_uri;

            if (strtolower($pageURI) == strtolower(substr($request_uri,0,-1)) || strtolower($pageURI) == strtolower($request_uri)) {
              $local_settings[$skey] = $svalue['value'];
            }

          }

        }

      }

    }

  }


  // Global settings ===========================================================
  // gmaps: This setting gets called wherever there is a main map. (index and contact)
  // amea: This setting gets called from in header.

  // pageBackground: The variable from this setting gets called by every page when the body opens.
  $pageStyle = "";
  if (isset($global_settings['pageBackground'])) {
    $pageBg = $global_settings['pageBackground'];
  }
  if (isset($local_settings['pageBackground'])) {
    $pageBg = $local_settings['pageBackground'];
  }

  // Set the background to a color or to an image.
  if (isset($pageBg) && $pageBg) {
    if (substr($pageBg, 0, 1) == '#') {
      $pageStyle .= "background: ".$pageBg.";";
    } else {
      $pageStyle .= "background: url(".$pageBg.");";
    }
  }


  // Set extra classes that should go in the body.
  $body_extra_class = "";
  if (isset($global_settings['pageFullWidth'])) {
    if ($global_settings['pageFullWidth'] == "true") {
      $body_extra_class .= " full-width ";
    }
  }


  // logoStyle: The variable from this setting is called from wherever there is the logo (header).
  $logoStyle = "";
  if ($global_settings['logoSize'] !== false) {
    $logoStyle .= "width:".$global_settings['logoSize']['width']."; height:".$global_settings['logoSize']['height'].";";
  }


  // Replace a language with another one.
  if ( isset($global_settings['replaceLanguage']) && count($template['allLanguages']['shortcutNames']) > 1 ) {
    // The value of this setting consists of the language we want to replace and the new language.
    // ie: "en, fr" replaces english with french.
    $langs = explode(", ", $global_settings['replaceLanguage']);
    for ($i=0; $i<count($langs); ++$i) {
      $langs[$i] = trim($langs[$i]);
    }

    // Iterate over all the available languages. Find the one we want to replace and replace its data-class,
    // and name.
    $langReplaced = false;
    for ($i=0; $i<count($template['allLanguages']['shortcutNames']); ++$i) {
      if ($template['allLanguages']['fullNames'][$i]['data-class'] === $langs[0]) {
        $template['allLanguages']['fullNames'][$i]['data-class'] = $langs[1];
        $template['allLanguages']['shortcutNames'][$i]['data-class'] = $langs[1];
        $template['allLanguages']['shortcutNames'][$i]['name'] = $langs[1];

        // The replaced language is selected. Set the template language to the new language.
        if ($template['allLanguages']['shortcutNames'][$i]['selected'] === true) {
          include_once __DIR__.'/langs/'.$langs[1].'.trans.php';
          $template['translate'] = $trans;
          $template['language'] = $langs[1];
          $global_settings['hideCategory'] = "true";
          // The new language does not exist in our system, so save the replaced language in a variable
          // so that we may use it where we need it.
          $oldLang = $langs[0];
        }
      }
    }
  }


  // Set the default language.
  // Redirect to the default language's page if theres no language specified in the URI and there are
  // many available languages.
  // If there is only one language then point the translation array to the default language's translation array.
  // If there is a language specified in the URI then load the page normally.
  if ( ! empty($global_settings['defaultLanguage']) ) {
    $defLang = $global_settings['defaultLanguage'];

    if (count($template['allLanguages']['shortcutNames']) > 0) {
      if ( isset($_GET['l'] ) === false) {
        // Get the default language's value and redirect to it.
        $defautLanguage = trim(strtoupper((string) $defLang));
        foreach ($template['allLanguages']['shortcutNames'] as $language) {
          if (trim(strtoupper((string) $language['name'])) == $defautLanguage) {
            header("HTTP/1.1 301 Moved Permanently");
            header('Location: '.$language['value']);
          }
        }
      }
    } else {
      include_once __DIR__.'/langs/'.$defLang.'.trans.php';
      $template['translate'] = $trans;
      $template['language'] = $defLang;
    }
  }

?>
