<?php

/*
This file is included at the top of every page. It constructs the opening html tag and the entire head section.
*/

include_once __DIR__ . '/template_globals.php';
include_once __DIR__ . '/get_settings.php';
?>
<html class="no-js" lang="<?php echo $template['language']; ?>">
    <head>

        <meta charset="UTF-8">

        <?php
        // Title
        if ( empty($template['pageTitle']['ensureSeoTitle']) ) {
            if ( ! empty($current_page_title) ) {
                $template['pageTitle']['ensureSeoTitle'] = $current_page_title . '|' . $template['merchant']['title'];
            } else {
                $template['pageTitle']['ensureSeoTitle'] = $template['merchant']['title'];
            }
        }
        echo '<title>' . $template['pageTitle']['ensureSeoTitle'] . '</title>';
        ?>

        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="<?php echo $template['pageDescription']['ensureSeoDescription']; ?>" />
        <meta name="keywords" content="<?php echo $template['keywords']; ?>" />
        <link rel="shortcut icon" href="<?php echo $template['faviconURL']; ?>">

        <?php if (isset($global_settings['fb-verification'])): ?>
            <meta name="facebook-domain-verification" content=<?php echo $global_settings['fb-verification']; ?> />
        <?php endif; ?>

        <?php
        // Set the alternate URLs to the default language.
        if (isset($global_settings['defaultLanguage']) && count($template['allLanguages']['shortcutNames']) === 0) {

            foreach($template['alternateURLs'] as $alternateURL) {
                $alternateURL['url'] = strtok($alternateURL['url'], "?");
                echo '<link rel="alternate" href="' . $alternateURL['url'] . '" hreflang="' . $global_settings['defaultLanguage'] . '" />';
            }

        } else {

            foreach($template['alternateURLs'] as $alternateURL) {
                echo '<link rel="alternate" href="' . $alternateURL['url'] . '" hreflang="' . $alternateURL['lang'] . '" />';
            }

        }
        ?>


        <?php
        // Graph tags ==================================================================

        foreach($template['graphModelTags'] as $current_tag) {

            $tag_property = $current_tag['property'];
            $tag_content = $current_tag['value'];

            if ( $tag_property == 'og:type' ) {
                $tag_content = 'organization';
            }
            else if ( $tag_property == 'og:title' && empty($global_settings['hideCategory']) !== false ) {
                $tag_content = $template['merchant']['title'];
            }
            else if ( $tag_property == 'og:url' ) {
                $tag_content = $template['alternateURLs'][0]['url'];
            }

            echo '<meta property= "' . $tag_property . '" content="' . $tag_content . '" />' . "\r\n";

        }
        ?>

        <?php // Assets ---------------------------------------------------------------- ?>
        <link href="https://fonts.googleapis.com/css?family=Arimo:400,700&display=swap&subset=greek-ext" rel="stylesheet">
        <link rel="stylesheet" href="<?php echo $template_path ?>/vendor/bootstrap/css/bootstrap.min.css" />
        <link rel="stylesheet" href="<?php echo $template_path ?>/css/main.css" media="screen" />
        <link rel="stylesheet" href="<?php echo $template_path ?>/template/template.css" media="screen" />
        <link rel="stylesheet" href="<?php echo $template_path ?>/css/extras.css" media="screen" />

        <script src="https://cdn.jsdelivr.net/npm/appblocks@1.3.0/dist/appblocks.min.js"></script>
        <script src="https://www.google.com/recaptcha/api.js?render=explicit"></script>
        <?php // Assets ---------------------------------------------------------------- ?>


        <?php // Google Analytics ====================================================== ?>
        <script>
            var galinks = ['<?php echo $template['settings']['4tyDomain']; ?>', '<?php echo $template['settings']['4tyshopsDomain']; ?>', location.hostname.indexOf('www.') == 0 ? location.hostname.substr(4) : location.hostname];
            (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
                    (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
                m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
            })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
            ga('create', '<?php echo $template['settings']['googleAnalyticsCode']; ?>', 'auto', {allowLinker: true});
            ga('require', 'linker');
            ga('linker:autoLink', galinks);
            ga('send', 'pageview');
        </script>
        <?php // ======================================================================= ?>

        <?php // Google tag manager ====================================================
        if (! empty($global_settings['googleTagManager'])) {
            $gtag_id = $global_settings['googleTagManager'];
        ?>
            <script>
                (function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
                new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
                j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
                'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
                })(window,document,'script','dataLayer', '<?php echo $gtag_id; ?>');
            </script>
        <?php
        }
        // =============================================================================
        ?>

        <?php // Google Global site tag ================================================
        if (! empty($global_settings['googleGlobalSiteTag'])) {
            $gtag_id = $global_settings['googleGlobalSiteTag'];
        ?>
            <script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo $gtag_id; ?>"></script>
            <script>
                window.dataLayer = window.dataLayer || [];
                function gtag() { dataLayer.push(arguments); }
                gtag('js', new Date());
                gtag('config', <?php echo $gtag_id; ?>);
            </script>
        <?php
        }
        // =============================================================================
        ?>

        <script>
            var templatePath = "<?php echo $template_path; ?>";
        </script>

        <?php // Facebook pixel ======================================================== ?>
        <?php if (empty($template['facebookPixelID']) === false)  { ?>
            <script>
                !function(f,b,e,v,n,t,s)
                {if(f.fbq)return;n=f.fbq=function(){n.callMethod?
                    n.callMethod.apply(n,arguments):n.queue.push(arguments)};
                    if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
                    n.queue=[];t=b.createElement(e);t.async=!0;
                    t.src=v;s=b.getElementsByTagName(e)[0];
                    s.parentNode.insertBefore(t,s)}(window, document,'script',
                    'https://connect.facebook.net/en_US/fbevents.js');
                fbq('init', <?php echo $template['facebookPixelID']; ?>);
                fbq('track', 'PageView');
            </script>
            <noscript>
                <img height="1" width="1" style="display:none" src="https://www.facebook.com/tr?id=test-pixel-id&amp;ev=PageView&amp;noscript=1"/>
            </noscript>
        <?php } ?>

        <?php
            // Displays a message saying the template is still under construction if loaded from a different domain.
            // if ($template_debug === true) {
            //     $current_index_url = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
            //     if (substr( $current_index_url, 0, 17 ) !== 'http://www.revpre') {
            //         echo "<p>We are NOT in the right page!</p>";
            //         echo '<div id="goaway"> <div class="goaway-image"><h3>The template is still under construction</h3></div> </div>';
            //         exit();
            //     }
            // }
        ?>

        <!-- <script>
            _atrk_opts = { atrk_acct:"+cqim1akGFL1vg", domain:"4ty.gr" ,dynamic: true};
            (function() { var as = document.createElement('script'); as.type = 'text/javascript'; as.async = true; as.src = "https://d31qbv1cthcecs.cloudfront.net/atrk.js"; var s = document.getElementsByTagName('script')[0];s.parentNode.insertBefore(as, s); })();
        </script> -->
        <!-- <noscript><img src="https://d5nxst8fruw4z.cloudfront.net/atrk.gif?account=+cqim1akGFL1vg" class="no-display" height="1" width="1" alt="noscript image for google" /></noscript> -->

        <?php if ($global_settings['tripAdvisor']): ?>
         <link rel="stylesheet" href="https://maxst.icons8.com/vue-static/landings/line-awesome/line-awesome/1.3.0/css/line-awesome.min.css">
        <?php endif; ?>

    </head>