/* jshint multistr: true, esversion: 6 */


const palletEl = document.createElement('div');
palletEl.innerHTML = '\
<h3 class="palette-toggle">Colors</h3>\
<ul id="colors">\
  <li c-for="color in data.colors" class="color">\
    <p class="colorbox" style="background-color:{color.id}" color="{color.name}"></p>\
    <p>{color.name}</p>\
  </li>\
</ul>\
';
palletEl.setAttribute('id', 'color-palette');
document.body.appendChild(palletEl);

const colorPallete = new AppBlock({

  el: palletEl,

  data: {
    // These are the available colors.
    colors: [
      {id: "#2eb3e0", name: "blue"},
      {id: "#82706c", name: "brown"},
      {id: "#9C634F", name: "brown2"},
      {id: "#72797f", name: "gray"},
      {id: "#8DB952", name: "green"},
      {id: "#46b05b", name: "green2"},
      {id: "#FF7029", name: "orange"},
      {id: "#f69374", name: "orange2"},
      {id: "#a26de3", name: "purple"},
      {id: "#ef0d1c", name: "red"},
      {id: "#d9c831", name: "yellow"},
      {id: "#FFCD00", name: "yellow2"}
    ],
    currentColor: "purple",
    basePath: templatePath + '/template/colors/'
  },

  methods: {
    beforeRender(app) {
      if (typeof(Storage) !== "undefined") {
        // Load the color from local storage if available.
        if (localStorage.getItem('colorTemplate')) {
          app.data.currentColor = localStorage.getItem('colorTemplate');
        }
      } else {
        console.log('==> Browser does not support local storage');
      }
      app.methods.updateColor(app);
    },
    updateColor(app) {
      let colorTemplatePath = app.data.basePath + app.data.currentColor + '/';
      if (!document.getElementById('color-template')) {
        let link  = document.createElement('link');
        link.id   = 'color-template';
        link.rel  = 'stylesheet';
        link.type = 'text/css';
        link.href = colorTemplatePath + 'color.css';
        link.media = 'screen';
        document.body.appendChild(link);
      } else {
        document.getElementById('color-template').setAttribute('href', colorTemplatePath + 'color.css');
      }
      app.methods.saveCurrentColor(app);
    },
    saveCurrentColor(app) {
      // Store the selected color in local storage (if available)
      if (typeof(Storage) !== "undefined") {
        if (localStorage.getItem('colorTemplate') !== app.data.currentColor) {
          localStorage.setItem("colorTemplate", app.data.currentColor);
        }
      }
    },
  },

  events: {
    'click .palette-toggle': function(e) {
      const app = this.Parent;
      if (app.el.style.transform === "translateY(0)" || app.el.style.transform === "translateY(0px)") {
        app.el.style.transform = "translateY(100%)";
      } else {
        app.el.style.transform = "translateY(0)";
      }
    },
    'click li.color>.colorbox': function(e) {
      const app = this.Parent;
      const target = e.target || e.srcElement;
      const sColor = target.getAttribute('color');
      if (sColor !== app.data.currentColor) {
        app.el.querySelectorAll('li.color>.colorbox.active').forEach(cEl => {
          cEl.classList.remove('active');
        });
        target.classList.add('active');
        app.data.currentColor = target.getAttribute('color');
        app.methods.updateColor(app);
      }
    }
  }

});